@@ -6,7 +6,7 @@ use warnings;
 use Dancer2::Plugin;
 use JSON::Syck;    # TODO 2: use Dancer2::Serializer::JSON; instead ?
 
-$Dancer2::Plugin::Locale::VERSION = '0.01';
+$Dancer2::Plugin::Locale::VERSION = '0.02';
 
 package Dancer2::Plugin::Locale::Obj;
 use Locales 0.33 unicode => 1;
@@ -59,10 +59,10 @@ on_plugin_import {
             die "Could not read locale directory ($locale_dir): $!\n";
         }
     }
-    no strict 'refs';
-    no warnings 'redefine';
+    no strict 'refs';                                                                                                                           ## no critic
+    no warnings 'redefine';                                                                                                                     ## no critic
     *Locale::Maketext::Utils::list_available_locales = sub {
-        return sort @available_locales;
+        return ( sort @available_locales );
     };
 
     # create classes that Locale::Maketext uses
@@ -74,18 +74,20 @@ on_plugin_import {
         # TODO 1: support tieing to CDB_File hash (e.g. if -f locale_cdb/$tag.cdb) so as not to load all the data into memory (see use_external_lex_cache)?
 
         # TODO 2: POD app w/ charset !utf8 == ick
-        eval "package Dancer2::Plugin::Locale::Obj::$tag;use base 'Dancer2::Plugin::Locale::Obj';our \$Encoding='utf8';our \%Lexicon;package Dancer2::Plugin::Locale;";
+        eval "package Dancer2::Plugin::Locale::Obj::$tag;use base 'Dancer2::Plugin::Locale::Obj';our \$Encoding='utf8';our \%Lexicon;package Dancer2::Plugin::Locale;";    ## no critic
 
         $JSON::Syck::ImplicitUnicode = 1;
-        no strict 'refs';
-        %{"Dancer2::Plugin::Locale::Obj::$tag\::Lexicon"} = $tag eq 'en' && !-e $file ? () : ( %{ JSON::Syck::LoadFile($file) } );    # TODO 1: instead: tie %{"Dancer2::Plugin::Locale::$tag\::Lexicon"}, 'Tie::Hash::ReadonlyStack', JSON::Syck::LoadFile($file);
+        no strict 'refs';                                                                                                                                                  ## no critic
+        %{"Dancer2::Plugin::Locale::Obj::$tag\::Lexicon"} = $tag eq 'en' && !-e $file ? () : ( %{ JSON::Syck::LoadFile($file) } );                                         # TODO 1: instead: tie %{"Dancer2::Plugin::Locale::$tag\::Lexicon"}, 'Tie::Hash::ReadonlyStack', JSON::Syck::LoadFile($file);
     }
 
     # TODO 2: Is there a better way to add template keyword?
     $dsl->app->add_hook(
         Dancer2::Core::Hook->new(
             name => 'before_template_render',
-            code => sub { $_[0]->{locale} ||= locale( $dsl, @_ ) },                                                                   # TODO 2. YAGNI? _[mt] => sub { locale->makevar(@_) } to parser
+            code => sub {
+                $_[0]->{locale} ||= sub { locale( $dsl, @_ ) }
+            },                                                                                                                                                             # TODO 2. YAGNI? _[mt] => sub { locale->makevar(@_) } to parser
         )
     );
 };
@@ -107,7 +109,7 @@ Dancer2::Plugin::Locale - Localize your Dancer2 application
 
 =head1 VERSION
 
-This document describes Dancer2::Plugin::Locale version 0.01
+This document describes Dancer2::Plugin::Locale version 0.02
 
 =head1 SYNOPSIS
 
@@ -136,17 +138,29 @@ A lazy façade to get a locale handle suitable to the request. The locale object
 
 It will be based on the session’s locale value if possible, then a configured default if possible, then 'en'.
 
-… TODO, sorry I needed to get this on CPAN for a consumer but will finish it ASAP …
+=head2 The object, in more detail
 
-=head2 The object, in detail
+The object is L<Locale::Maketext::Utils> based.
 
-… TODO, sorry I needed to get this on CPAN for a consumer but will finish it ASAP …
+L<Locale::Maketext::Utils> extends L<Locale::Maketext> a number of ways including:
 
-=head3 CLDR
+=over 4
 
-… TODO, sorry I needed to get this on CPAN for a consumer but will finish it ASAP …
+=item * It shifts toward CLDR based functionality which means you no longer have to create locale specific variants of code in each locale’s class.
 
-=head3 Available locales.
+=item * Because of that and other utils it has, creating and dealing with the locale subclasses classes is much easier.
+
+=item * The object is a multiton (AKA an argument based singleton):  L<Locale::Maketext::Utils/"Argument based singleton">
+
+=item * Adds a number of helpful methods: L<Locale::Maketext::Utils/METHODS>
+
+=item * More sane fallback and lookup failure hooks: L<Locale::Maketext::Utils/"Automatically _AUTO'd Failure Handling with hooks">
+
+=item * Adds a very handy set of bracket notation methods (CLDR when possible)  L</"Bracket Notation">
+
+=back
+
+=head3 Available Locales
 
 The locales available are determined by the lexicon files found in the appdir’s C<locale/> directory.
 
@@ -156,12 +170,15 @@ Tip: To make them available to your UI you could simply symlink C<…/locale/> t
 
 =head3 Lexicon
 
-A lexicon is a simple key/value hash where the key is the phrase and the value is the translation.
+A lexicon is a simple key/value hash  where the key is the phrase and the value is the translation.
 
-For example,
+For example,in pseudo code:
 
+    # source phrase => target phrase
     'Hello World' => 'Bonjour Monde'
 
+Each locale will have a lexicon hash in a file as desrcibed in L</"Available Locales">.
+
 The hash must be written in JSON format and be utf8 encoded.
 
 Don’t be afraid of non-ASCII characters, just put them in the file as the character and it will work fine (if it doesn’t then it can help you track down bugs faster, win win!).
@@ -170,7 +187,27 @@ Don’t be afraid of non-ASCII characters, just put them in the file as the char
 
 =head3 Bracket Notation
 
-… TODO, sorry I needed to get this on CPAN for a consumer but will finish it ASAP …
+Bracket notation is described a bit more at L<Locale::Maketext/BRACKET NOTATION> but is essentially a format to allow you to notate–within left and right square brackets, hence the name–dynamic portions of a phrase.
+
+For example, include a non-translatable ever-changing name:
+
+    locale->maketext('Your email address, [_1], has been unsubscribed.', $email)
+
+or a number formatted according to the object’s locale’s CLDR data:
+
+    locale->maketext('You are user [numf,_1] of [numf,_2].', $place, $count)
+
+The bracket notation improvements over the core L<Locale::Maketext> can be categoraized as follows:
+
+=over 4
+
+=item * L<improved core Locale::Maketext bracket notation methods|http://search.cpan.org/perldoc?Locale::Maketext::Utils#Improved_Bracket_Notation>
+
+=item * L<additional bracket notation methods|http://search.cpan.org/perldoc?Locale::Maketext::Utils#Additional_bracket_notation_methods>
+
+=item * L<output() bracket notation methods|http://search.cpan.org/perldoc?Locale::Maketext::Utils#output()>
+
+=back
 
 =head2 Misc Info
 
